import sys
from xpaper import windows
from xpaper import linux


def change(imagepath):
    if sys.platform in ["win32", "cygwin"]:
        windows.setwallpaper(imagepath)
    else:
        linux.setwallpaper(imagepath)


def get():
    if sys.platform in ["win32", "cygwin"]:
        return windows.getwallpaper()



import sys
import ctypes

SPI_SETDESKWALLPAPER = 0x0014
SPI_GETDESKWALLPAPER = 0x0073

def setwallpaper(imagepath):
    imagepath = imagepath.replace("/", "\\")
    if sys.version_info[0] is 2:
        ctypes.windll.user32.SystemParametersInfoA(SPI_SETDESKWALLPAPER, 0, imagepath, 3)
    else:
        ctypes.windll.user32.SystemParametersInfoW(SPI_SETDESKWALLPAPER, 0, imagepath, 3)


def getwallpaper():
    unicode_buffer = ctypes.create_unicode_buffer(512)
    string_buffer = ctypes.create_string_buffer(512)
    if sys.version_info[0] is 2:
        try:
            ctypes.windll.user32.SystemParametersInfoA(SPI_GETDESKWALLPAPER,len(string_buffer),string_buffer,0)
            return string_buffer.value
        except:
            ctypes.windll.user32.SystemParametersInfoW(SPI_GETDESKWALLPAPER, len(unicode_buffer), unicode_buffer, 0)
            return unicode_buffer.value
    else:
        try:
            ctypes.windll.user32.SystemParametersInfoW(SPI_GETDESKWALLPAPER, len(unicode_buffer), unicode_buffer, 0)
            return unicode_buffer.value
        except:
            ctypes.windll.user32.SystemParametersInfoA(SPI_GETDESKWALLPAPER,len(string_buffer),string_buffer,0)
            return string_buffer.value



import subprocess
import os

def setwallper(imagepath):
    desktop_session = os.environ.get("DESKTOP_SESSION")
    if desktop_session is not None:
        desktop_session = desktop_session.lower()
        if desktop_session in ["gnome", "unity", "cinnamon", "pantheon"]:
            subprocess.Popen("gsettings", "set", "org.gnome.desktop.background", "picture-uri", "'file://%s'" % imagepath)
        elif desktop_session == "mate":
            try:
                subprocess.Popen("dconf", "write", "/org/mate/desktop/background/picture-filename", imagepath)
            except:
                subprocess.Popen("gsettings", "set", "org.mate.background", "picture-filename", "'%s'" % imagepath)
            finally:
                 subprocess.Popen("mateconftool-2","-t","string","--set","/desktop/mate/background/picture_filename",'"%s"' % imagepath)
        elif desktop_session == "lxde":
            try:
                subprocess.Popen("pcmanfm", "-w", imagepath)
            except:
                subprocess.Popen("pcmanfm --set-wallpaper %s --wallpaper-mode=scaled" % imagepath)
        elif desktop_session == "xfce" or desktop_session.startswith("xubuntu"):
            subprocess.Popen("xfconf-query", "-c", "xfce4-desktop", "-p", "/backdrop/screen0/monitor0/workspace0/last-image", "-s", imagepath)       
